using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using CalendarClient.Calendar;
using System.Collections;

namespace CalendarClient
{

    public partial class Main : Form
    {
        protected bool connected = false;

        protected String username = "";
        protected String password = "";
        List<AppointmentType> types = new List<AppointmentType>();
        CalendarService service = new CalendarService();
                    
        public Main()
        {
            InitializeComponent();
        }

        void connect(object sender, EventArgs e)
        {
            if (connected)
            {
                connected = false;
                this.statusLabel.Text = "Service Not Connected";
            }
            else
            {   
                try 
                {
                    this.username = textUsername.Text;
                    this.password = textPassword.Text;

                    // Reset Username and Password Field
                    textUsername.Text = "";
                    textPassword.Text = "";

                    // Write Time in Status Bar
                    String timeString = service.getTime();
                    this.statusLabel.Text = timeString;

                    // Init Types
                    stringArray[] apptypes = service.getTypes();
                    for (int i = 0; i < apptypes.Length; i++)
                    {
                        String[] atype = apptypes[i].item;
                        if(atype.Length==2)
                            this.types.Add(new AppointmentType(atype[0],atype[1]));
      
                    }

                    connected = true;

                } 
                catch(Exception ex) {
                    Console.WriteLine(ex.ToString());
                }

            }
        }

        /// <summary>
        /// Get all appointments for the user.
        /// View each appointment as an item in the listview
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void buttonFind_Click(object sender, EventArgs e)
        {
            this.disableInput();

            if (connected && service != null)
            {
                this.listAppointment.Clear();
                stringArray[] apps = service.getAppointments(username,password);
                for (int i = 0; i < apps.Length; i++)
                {
                    Appointment app = new Appointment();
                    String[] item = apps[i].item;
                    app.id = item[0];
                    app.title = item[1];
                    app.description = item[2];
                    app.date = item[3];
                    app.typeId = item[4];

                    AppointmentListViewItem elem = new AppointmentListViewItem();
                    elem.Text = app.title;
                    elem.appointment = app;
                    
                    this.listAppointment.Items.Add(elem);
                }
                

                
            }
        }

        private void listAppointment_SelectedIndexChanged(object sender, EventArgs e)
        {
            ListView.SelectedListViewItemCollection elems = this.listAppointment.SelectedItems;
            IEnumerator enumerator = elems.GetEnumerator();
            if (enumerator.MoveNext())
            {
                AppointmentListViewItem item = (AppointmentListViewItem)enumerator.Current;
                this.textBoxTitle.Text = item.appointment.title;
                this.textBoxDescription.Text = item.appointment.description;
            }
        }

        private void buttonCreate_Click(object sender, EventArgs e)
        {
            enableInput();    
        }

        private void enableInput()
        {
            this.textBoxTitle.Enabled = true;
            this.textBoxDescription.Enabled = true;
            this.buttonCreateApp.Enabled = true;
        }

        private void disableInput()
        {
            this.textBoxTitle.Enabled = false;
            this.textBoxTitle.Text = "";
            this.textBoxDescription.Enabled = false;
            this.textBoxDescription.Text = "";
            this.buttonCreateApp.Enabled = false;
        }

        private void buttonCreateApp_Click(object sender, EventArgs e)
        {
            
            if (connected)
            {
                DateTime d = DateTime.Now;
                String id = service.createAppointment(username, password, this.textBoxTitle.Text, this.textBoxDescription.Text, d.Millisecond.ToString() , types[0].id, 1);
                this.buttonFind_Click(null, null);
            }
            disableInput();
        }

        private void buttonDelete_Click(object sender, EventArgs e)
        {
            ListView.SelectedListViewItemCollection elems = this.listAppointment.SelectedItems;
            IEnumerator enumerator = elems.GetEnumerator();
            if (enumerator.MoveNext())
            {
                AppointmentListViewItem item = (AppointmentListViewItem)enumerator.Current;
                String appId = item.appointment.id;
                service.deleteAppointment(username, password, appId);
                this.buttonFind_Click(null, null);
            }
        }

        private void btnCreateUser_Click(object sender, EventArgs e)
        {
            if (!this.textUsername.Text.Equals("") && !this.textPassword.Text.Equals(""))
            {
                username = this.textUsername.Text;
                password = this.textPassword.Text;
                if (service.createUser(username, password))
                {
                    this.statusLabel.Text = "User " + username + " created";
                }
                else
                {
                    this.statusLabel.Text = "Error creating user";
                }

            }
        }
    }
}